@@ -7,9 +7,9 @@ if [[ $INSTALL_OPTIONAL != false ]]; then
 	[[ $(command -v gdb) == "" ]] && echo "Installing gdb" && extension --install gdb && echo "Finished gdb"
 fi
 
-[[ $(c++ --version | grep 14.2.0) == "" ]] && BUILD_ALL=true
+#[[ $(c++ --version | grep 15.2.0) == "" ]] && BUILD_ALL=true
 
-if [ $BUILD_ALL == "false" ] && [[ $(command -v gfortran) == "" ]]; then
+if [ $BUILD_ALL == "false" ] && [[ $(gcc --version | sed 2,5d | cut -d " " -f 3) != 15.2.0 ]]; then
 	echo "gcc" 											>> $EXTENSION/build_order.txt
 fi
 if [ $BUILD_ALL == "true" ]; then
